@@ -18,7 +18,7 @@ import re
 import typing as t
 import warnings
 from functools import lru_cache
-from pathlib import PosixPath
+from pathlib import Path
 
 import dask.array as da
 import h5py
@@ -231,13 +231,14 @@ class Tiler(StepABC):
         self.image = image
         self._metadata = metadata
         self.channels = metadata.get(
-            "channels", list(range(metadata.get("size_c", 0)))
-        )
-        self.ref_channel = (
-            self.get_channel_index(parameters.ref_channel)
-            or self.backup_ref_channel
+            "channels",
+            list(range(metadata.get("size_c", 0))),
         )
 
+        self.ref_channel = self.get_channel_index(parameters.ref_channel)
+        if self.ref_channel is None:
+            self.ref_channel = self.backup_ref_channel
+
         self.ref_channel = self.get_channel_index(parameters.ref_channel)
         self.tile_locs = tile_locs
         try:
@@ -302,7 +303,7 @@ class Tiler(StepABC):
     def from_h5(
         cls,
         image,
-        filepath: t.Union[str, PosixPath],
+        filepath: t.Union[str, Path],
         parameters: t.Optional[TilerParameters] = None,
     ):
         """
