@@ -6,12 +6,12 @@ Example of usage:
 
 fpath = "/home/alan/Documents/dev/skeletons/scripts/data/16543_2019_07_16_aggregates_CTP_switch_2_0glu_0_0glu_URA7young_URA8young_URA8old_01/URA8_young018.h5"
 
-trap_id = 9
-trange = list(range(0, 30))
+tile_id = 9
+trange = list(range(0, 10))
 ncols = 8
 
 riv = remoteImageViewer(fpath)
-riv.plot_labelled_trap(trap_id, trange, [0], ncols=ncols)
+riv.plot_labelled_trap(tile_id, trange, [0], ncols=ncols)
 
 """
 
@@ -27,10 +27,9 @@ from PIL import Image
 from skimage.morphology import dilation
 
 from agora.io.cells import Cells
-from agora.io.writer import load_attributes
-from aliby.io.image import dispatch_image
+from agora.io.metadata import dispatch_metadata_parser
 from aliby.tile.tiler import Tiler, TilerParameters
-from aliby.utils.plot import stretch_image
+from aliby.utils.plot import stretch_clip
 
 default_colours = {
     "Brightfield": "Greys_r",
@@ -56,37 +55,17 @@ def custom_imshow(a, norm=None, cmap=None, *args, **kwargs):
     )
 
 
-class localImageViewer:
-    """
-    Fast access to Images segmented locally without tiling
-    from image.h5 objects.
-    """
-
-    def __init__(self, h5file, data_source=None):
-        self._hdf = h5py.File(h5file)
-        self.positions = list(self._hdf.keys())
-        self.current_position = self.positions[0]
-
-    def plot_position(self, channel=0, tp=0, z=0, stretch=True):
-        pixvals = self._hdf[self.current_position][channel, tp, ..., z]
-        if stretch:
-            minval = np.percentile(pixvals, 0.5)
-            maxval = np.percentile(pixvals, 99.5)
-            pixvals = np.clip(pixvals, minval, maxval)
-            pixvals = ((pixvals - minval) / (maxval - minval)) * 255
-
-        Image.fromarray(pixvals.astype(np.uint8))
-
-
 class BaseImageViewer(ABC):
     def __init__(self, fpath):
 
         self._fpath = fpath
-        attrs = load_attributes(fpath)
+        attrs = dispatch_metadata_parser(fpath.parent)
         self._logfiles_meta = {}
-        self._logfiles_meta["channels"] = attrs["channels/channel"]
 
         self.image_id = attrs.get("image_id")
+        if self.image_id is None:
+            with h5py.File(fpath, "r") as f:
+                self.image_id = f.attrs.get("image_id")
 
         assert self.image_id is not None, "No valid image_id found in metadata"
 
@@ -112,6 +91,7 @@ class LocalImageViewer(BaseImageViewer):
     """
     Tool to generate figures from local files, either zarr or files organised
     in directories.
+    TODO move common functionality from RemoteImageViewer to BaseImageViewer
     """
 
     def __init__(self, results_path: str, data_path: str):
@@ -133,30 +113,28 @@ class LocalImageViewer(BaseImageViewer):
         self.cells = Cells.from_source(results_path)
 
 
-class remoteImageViewer(BaseImageViewer):
+class RemoteImageViewer(BaseImageViewer):
     """
     This ImageViewer combines fetching remote images with tiling and outline display.
     """
 
+    _credentials = ("host", "username", "password")
+
     def __init__(
         self,
         results_path: str,
         server_info: t.Dict[str, str],
     ):
-        self.super().__init__(results_path)
+        super().__init__(results_path)
 
-        from aliby.io.omero import Image as OImage
+        from aliby.io.omero import UnsafeImage as OImage
 
-        self._image_class = OImage
+        self._server_info = server_info or {
+            k: attrs["parameters"]["general"][k] for k in self._credentials
+        }
 
-        self._server_info = (
-            server_info or attrs["parameters"]["general"]["server_info"]
-        )
-
-        with dispatch_image(self.image_id)(
-            self.image_id, **self.server_info
-        ) as image:
-            self.tiler = Tiler.from_hdf5(image, results_path)
+        self._image_instance = OImage(self.image_id, **self._server_info)
+        self.tiler = Tiler.from_h5(self._image_instance, results_path)
 
         self.cells = Cells.from_source(results_path)
 
@@ -227,25 +205,26 @@ class remoteImageViewer(BaseImageViewer):
         if z is None:
             z = 0
 
-        server_info = server_info or self.server_info
+        server_info = server_info or self._server_info
         channels = 0 or self._find_channels(channels)
         z = z or self.tiler.ref_z
 
         ch_tps = [(channels[0], tp) for tp in tps]
-        with self._image_class(self.image_id, **server_info) as image:
-            self.tiler.image = image.data
-            for ch, tp in ch_tps:
-                if (ch, tp) not in self.full:
-                    self.full[(ch, tp)] = self.tiler.get_tiles_timepoint(
-                        tp, channels=[ch], z=[z]
-                    )[:, 0, 0, ..., z]
-            requested_trap = {tp: self.full[(ch, tp)] for ch, tp in ch_tps}
 
-            return requested_trap
+        image = self._image_instance
+        self.tiler.image = image.data
+        for ch, tp in ch_tps:
+            if (ch, tp) not in self.full:
+                self.full[(ch, tp)] = self.tiler.get_tiles_timepoint(
+                    tp, channels=[ch], z=[z]
+                )[:, 0, 0, z, ...]
+        requested_trap = {tp: self.full[(ch, tp)] for ch, tp in ch_tps}
+
+        return requested_trap
 
     def get_labelled_trap(
         self,
-        trap_id: int,
+        tile_id: int,
         tps: t.Union[range, t.Collection[int]],
         channels=None,
         concatenate=True,
@@ -255,12 +234,12 @@ class remoteImageViewer(BaseImageViewer):
         Core method to fetch traps and labels together
         """
         imgs = self.get_pos_timepoints(tps, channels=channels, **kwargs)
-        imgs_list = [x[trap_id] for x in imgs.values()]
+        imgs_list = [x[tile_id] for x in imgs.values()]
         outlines = [
-            self.cells.at_time(tp, kind="edgemask").get(trap_id, [])
+            self.cells.at_time(tp, kind="edgemask").get(tile_id, [])
             for tp in tps
         ]
-        lbls = [self.cells.labels_at_time(tp).get(trap_id, []) for tp in tps]
+        lbls = [self.cells.labels_at_time(tp).get(tile_id, []) for tp in tps]
         lbld_outlines = [
             np.stack([mask * lbl for mask, lbl in zip(maskset, lblset)]).max(
                 axis=0
@@ -274,7 +253,7 @@ class remoteImageViewer(BaseImageViewer):
             imgs_list = np.concatenate(imgs_list, axis=1)
         return lbld_outlines, imgs_list
 
-    def get_images(self, trap_id, trange, channels, **kwargs):
+    def get_images(self, tile_id, trange, channels, **kwargs):
         """
         Wrapper to fetch images
         """
@@ -283,13 +262,13 @@ class remoteImageViewer(BaseImageViewer):
 
         for ch in self._find_channels(channels):
             out, imgs[ch] = self.get_labelled_trap(
-                trap_id, trange, channels=[ch], **kwargs
+                tile_id, trange, channels=[ch], **kwargs
             )
         return out, imgs
 
     def plot_labelled_trap(
         self,
-        trap_id: int,
+        tile_id: int,
         channels,
         trange: t.Union[range, t.Collection[int]],
         remove_axis: bool = False,
@@ -309,7 +288,7 @@ class remoteImageViewer(BaseImageViewer):
 
         Parameters
         ----------
-        trap_id : int
+        tile_id : int
             Identifier of trap
         channels : Union[str, int]
             Channels to use
@@ -346,7 +325,7 @@ class remoteImageViewer(BaseImageViewer):
         nrows = int(np.ceil(len(trange) / ncols))
         width = self.tiler.tile_size * ncols
 
-        out, images = self.get_images(trap_id, trange, channels, **kwargs)
+        out, images = self.get_images(tile_id, trange, channels, **kwargs)
 
         # dilation makes outlines easier to see
         out = dilation(out).astype(float)
@@ -364,7 +343,7 @@ class remoteImageViewer(BaseImageViewer):
         ), "Invalid norm argument."
 
         if norm and norm in ("l1", "l2", "max"):
-            images = {k: stretch_image(v) for k, v in images.items()}
+            images = {k: stretch_clip(v) for k, v in images.items()}
 
         images = [concat_pad(img, width, nrows) for img in images.values()]
         # TODO convert to RGB to draw fluorescence with colour
