@@ -2,6 +2,7 @@
 import typing as t
 from abc import abstractmethod
 
+import h5py
 import numpy as np
 import pandas as pd
 
@@ -20,7 +21,7 @@ class LineageProcessParameters(ParametersABC):
 
 class LineageProcess(PostProcessABC):
     """
-    Lineage process that must be passed a (N,3) lineage matrix (where the coliumns are trap, mother, daughter respectively)
+    Lineage process that must be passed a (N,3) lineage matrix (where the columns are trap, mother, daughter respectively)
     """
 
     def __init__(self, parameters: LineageProcessParameters):
@@ -52,11 +53,20 @@ class LineageProcess(PostProcessABC):
             data, lineage=lineage, *extra_data
         )
 
-    def get_lineage_information(self, signal):
-        if "mother_label" in signal.index.names:
+    def get_lineage_information(self, signal=None, merged=True):
+
+        if signal is not None and "mother_label" in signal.index.names:
             lineage = get_index_as_np(signal)
-        elif self.cells is not None:
-            lineage = self.cells.mothers_daughters
+        elif hasattr(self, "lineage"):
+            lineage = self.lineage
+        elif hasattr(self, "cells"):
+            with h5py.File(self.cells.filename, "a") as f:
+                if (lineage_loc := "modifiers/lineage_merged") in f and merged:
+                    lineage = f.get(lineage_loc)[()]
+                elif (lineage_loc := "modifiers/lineage)") in f:
+                    lineage = f.get(lineage_loc)[()]
+                elif self.cells is not None:
+                    lineage = self.cells.mothers_daughters
         else:
             raise Exception("No linage information found")
         return lineage
