@@ -56,20 +56,37 @@ class BudMetric(LineageProcess):
 
         """
         mothers_mat = np.zeros((len(md), signal.shape[1]))
+        flag = 0  # Flag determines if mothers (1), daughters (2) or both were missing (3)
+
+        md_ = {k: md[k] for k in signal.index.intersection(md.keys())}
+        if len(md_) < len(md):
+            flag += 1
+
+        dau_flags = False
         for i, daughters in enumerate(md.values()):
-            dau_vals = signal.loc[set(daughters)].droplevel("trap")
-            sorted_da_ids = dau_vals.sort_index(level="cell_label")
-            tp_fvt = sorted_da_ids.apply(
-                lambda x: x.last_valid_index(), axis=0
+            if len(daughters_inter := signal.index.intersection(daughters)):
+
+                dau_vals = signal.loc[set(daughters_inter)].droplevel("trap")
+                sorted_da_ids = dau_vals.sort_index(level="cell_label")
+                tp_fvt = sorted_da_ids.apply(
+                    lambda x: x.last_valid_index(), axis=0
+                )
+
+                tp_fvt = sorted_da_ids.index.get_indexer(tp_fvt)
+                tp_fvt[tp_fvt < 0] = sorted_da_ids.shape[0] - 1
+
+                buds_metric = np.choose(tp_fvt, sorted_da_ids.values)
+                # mothers_mat[i, tp_fvt[0] : tp_fvt[0] + len(buds_metric)] = buds_metric
+                mothers_mat[i] = buds_metric
+
+        if dau_flags:
+            flag += 2
+
+        if flag:
+            print(
+                f"BudMetric: Cell labels of the kind {('mother','daughter','both')[flag]} were dropped"
             )
 
-            tp_fvt = sorted_da_ids.index.get_indexer(tp_fvt)
-            tp_fvt[tp_fvt < 0] = sorted_da_ids.shape[0] - 1
-
-            buds_metric = np.choose(tp_fvt, sorted_da_ids.values)
-            # mothers_mat[i, tp_fvt[0] : tp_fvt[0] + len(buds_metric)] = buds_metric
-            mothers_mat[i] = buds_metric
-
         df = pd.DataFrame(mothers_mat, index=md.keys(), columns=signal.columns)
         if len(df):
             df.index.names = signal.index.names
